@@ -1,18 +1,21 @@
 from redis import Redis as Redis
 from ghettoq.backends.base import BaseBackend
 
+DEFAULT_PORT = 6379
+
 
 class RedisBackend(BaseBackend):
 
     def establish_connection(self):
+        self.port = self.port or DEFAULT_PORT
         return Redis(host=self.host, port=self.port, db=self.database,
-                     timeout=self.timeout)
+                     password=self.password)
 
     def put(self, queue, message):
-        self.client.push(queue, message, tail=True)
+        self.client.lpush(queue, message)
 
     def get(self, queue):
-        return self.client.pop(queue)
+        return self.client.rpop(queue)
 
     def purge(self, queue):
         return self.client.delete(queue)
